==> dl.php?src=linea21_1_4.zip: linea21/languages/en/lang_theme.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage en
 * @author linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



/*	confirmation
 *  	*/
$lang['theme']['name']="theme";
$lang['theme']['confirm_add'] = "Theme successfully added\n";
$lang['theme']['confirm_mod'] = "Theme successfully updated\n";
$lang['theme']['confirm_sup'] ="Theme successfully deleted\n";

/*	nommage rubrique add / mod /det
 *  	*/
$lang['theme']['add_title']="Add data about the new ".$lang['theme']['name'];
$lang['theme']['mod_title']="Edit data about ".$lang['theme']['name'];


/*	nommage rubrique module
 *  	*/
$lang['theme']['add']= "Add a new ".$lang['theme']['name'];
$lang['theme']['mod']= "Edit ".$lang['theme']['name'];
$lang['theme']['sup']= "Delete ".$lang['theme']['name'];
$lang['theme']['det']= ucfirst($lang['theme']['name']) . " details";
$lang['theme']['list']= "View themes";
$lang['sdtheme']['det']= "Main theme details";

/*	nommage élément rubrique
 *  	*/
$lang['theme']['is_root']="Main theme ?";
$lang['theme']['denomination']="Denomination";
$lang['theme']['sdtheme']="Main theme";
$lang['theme']['photouri']="Associated picture";
$lang['theme']['statut']="Status";

$lang['theme']['description']="Description";
$lang['theme']['description_all']="Global description (for all modules)";
$lang['theme']['desc_all']="Global description (mutual).";
$lang['theme']['description_det']= $lang['theme']['name']." description by module.";
$lang['theme']['desc_det_project']="Projects  (description)";
$lang['theme']['desc_det_dashboard']="SDI Dashboard (description)";
$lang['theme']['desc_det_publication']="Publications (description)";
$lang['theme']['desc_det_news']="News (description)";
$lang['theme']['desc_det_workshop']="Workgroups (description)";
$lang['theme']['desc_det_forum']="Forums (description)";

/*	nommage rubrique sup
 *  	*/
$lang['theme']['sup_massd']= "Delete all the associated resources";
$lang['theme']['sup_massm']= "Attach all the associated resources to another theme";
$lang['theme']['sup_transfert']= "Transfer theme";

/*	nommage quickbox
 *  	*/
$lang['theme']['qb_titleadd']=" latest additions";
$lang['theme']['qb_titlemod']=" latest modifications";
$lang['theme']['qb_titlesup']=" latest deletions";

/*	messages
 *  	*/
$lang['theme']['object_notdenomination']="Denomination is required";
$lang['theme']['object_notSDtheme']="Association with SD theme is required";
$lang['theme']['object_notdesc_completed']="Description for each module is required";
$lang['theme']['object_notstatus']="Status is required";
$lang['theme']['sup_nomethod']="Deletion methods is required!";
$lang['theme']['sup_notheme']="Transfer theme is required!";
$lang['theme']['sup_mass_delete']="Caution, theme deletion will also delete attached resources!";
$lang['theme']['sup_mass_modify']="Caution, theme transfer will also transfer attached resources!";

/*	rubrique d'aide
 *  	*/
$lang['theme']['help_add1']="To add a theme, please insert the required informations in the form above";
$lang['theme']['help_add2']="An association with SD theme is required";
$lang['theme']['help_add3']="After submitting the form, check your data in the summary";
$lang['theme']['help_add4']='After checking summary, click the \'review settings\' button to make new changes';


$lang['theme']['help_list1']="Click on theme titles to display more informations";
$lang['theme']['help_list2']="Delete theme by clicking on the delete icon linked in";
$lang['theme']['help_list3']="Edit theme by clicking on the edit icon linked in";
$lang['theme']['help_list4']="To add a theme, please insert the required informations in the form above";
$lang['theme']['help_list5']="To perform search on themes only, just click the 'search' link";


$lang['theme']['help_mod1']="To edit a theme, please insert the required informations in the form above";
$lang['theme']['help_mod2']="Once the form submitted, check your data in the summary";
$lang['theme']['help_mod3']='After checking summary, click the \'review settings\' button to make new changes';


$lang['theme']['help_det1']="Click on theme titles to display this parent scale";
$lang['theme']['help_det2']="Delete theme by clicking on the delete icon linked in";
$lang['theme']['help_det3']="Edit theme by clicking on the edit icon linked in";
$lang['sdtheme']['help_det1']="This theme is the SD Root. this root is not editable or deletable";


$lang['theme']['help_sup1']="Deletion method is required";
$lang['theme']['help_sup2']="Security code is required";
$lang['theme']['help_sup3']="Caution, theme's deletion involves changes in the whole application; this deletion is recommanded to expert only";

?>

==> dl.php?src=linea21_1_7.zip: linea21/languages/en/lang_theme.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage en
 * @author linea21 <info@linea21.com> & Stéphanie Loubechine
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */



/*	confirmation
 *  	*/
$lang['theme']['name']="theme";
$lang['theme']['confirm_add'] = "Theme successfully added\n";
$lang['theme']['confirm_mod'] = "Theme successfully updated\n";
$lang['theme']['confirm_sup'] ="Theme successfully deleted\n";

/*	nommage rubrique add / mod /det
 *  	*/
$lang['theme']['add_title']="Add data about the new ".$lang['theme']['name'];
$lang['theme']['mod_title']="Edit data about ".$lang['theme']['name'];


/*	nommage rubrique module
 *  	*/
$lang['theme']['add']= "Add a new ".$lang['theme']['name'];
$lang['theme']['mod']= "Edit ".$lang['theme']['name'];
$lang['theme']['sup']= "Delete ".$lang['theme']['name'];
$lang['theme']['det']= ucfirst($lang['theme']['name']) . " details";
$lang['theme']['list']= "View themes";
$lang['sdtheme']['det']= "Main theme details";

/*	nommage élément rubrique
 *  	*/
$lang['theme']['is_root']="Main theme ?";
$lang['theme']['denomination']="Denomination";
$lang['theme']['sdtheme']="Main theme";
$lang['theme']['photouri']="Associated picture";
$lang['theme']['statut']="Status";

$lang['theme']['description']="Description";
$lang['theme']['description_all']="Global description (for all modules)";
$lang['theme']['desc_all']="Global description (mutual).";
$lang['theme']['description_det']= $lang['theme']['name']." description by module.";
$lang['theme']['desc_det_project']="Projects  (description)";
$lang['theme']['desc_det_dashboard']="Dashboard (description)";
$lang['theme']['desc_det_publication']="Publications (description)";
$lang['theme']['desc_det_news']="News (description)";
$lang['theme']['desc_det_workshop']="Workgroups (description)";
$lang['theme']['desc_det_forum']="Forums (description)";

/*	nommage rubrique sup
 *  	*/
$lang['theme']['sup_massd']= "Delete all the associated resources";
$lang['theme']['sup_massm']= "Attach all the associated resources to another theme";
$lang['theme']['sup_transfert']= "Transfer theme";

/*	nommage quickbox
 *  	*/
$lang['theme']['qb_titleadd']=" latest additions";
$lang['theme']['qb_titlemod']=" latest modifications";
$lang['theme']['qb_titlesup']=" latest deletions";

/*	messages
 *  	*/
$lang['theme']['object_notdenomination']="Denomination is required";
$lang['theme']['object_notSDtheme']="Association with SD theme is required";
$lang['theme']['object_notdesc_completed']="Description for each module is required";
$lang['theme']['object_notstatus']="Status is required";
$lang['theme']['sup_nomethod']="Deletion methods is required!";
$lang['theme']['sup_notheme']="Transfer theme is required!";
$lang['theme']['sup_mass_delete']="Caution, theme deletion will also delete attached resources!";
$lang['theme']['sup_mass_modify']="Caution, theme transfer will also transfer attached resources!";

/*	rubrique d'aide
 *  	*/
$lang['theme']['help_add1']="To add a theme, please insert the required informations in the form above";
$lang['theme']['help_add2']="An association with SD theme is required";
$lang['theme']['help_add3']="After submitting the form, check your data in the summary";
$lang['theme']['help_add4']='After checking summary, click the \'review settings\' button to make new changes';


$lang['theme']['help_list1']="Click on theme titles to display more informations";
$lang['theme']['help_list2']="Delete theme by clicking on the delete icon linked in";
$lang['theme']['help_list3']="Edit theme by clicking on the edit icon linked in";
$lang['theme']['help_list4']="To add a theme, please insert the required informations in the form above";
$lang['theme']['help_list5']="To perform search on themes only, just click the 'search' link";


$lang['theme']['help_mod1']="To edit a theme, please insert the required informations in the form above";
$lang['theme']['help_mod2']="Once the form submitted, check your data in the summary";
$lang['theme']['help_mod3']='After checking summary, click the \'review settings\' button to make new changes';


$lang['theme']['help_det1']="Click on theme titles to display this parent scale";
$lang['theme']['help_det2']="Delete theme by clicking on the delete icon linked in";
$lang['theme']['help_det3']="Edit theme by clicking on the edit icon linked in";
$lang['sdtheme']['help_det1']="This theme is the SD Root. this root is not editable or deletable";


$lang['theme']['help_sup1']="Deletion method is required";
$lang['theme']['help_sup2']="Security code is required";
$lang['theme']['help_sup3']="Caution, theme's deletion involves changes in the whole application; this deletion is recommanded to expert only";

?>
